local L = AceLibrary("AceLocale-2.2"):new("Bartender3")

function Bartender3:PopulateOptions()
	self.options = {
		type = "group",
		args = {
			lock = {
				order = 1,
				name = "Lock", 
				type = "toggle",
				desc = "Toggle the lock of the action bars.",
				get = function() return not Bartender3.unlock end,
				set = function(v)
					if Bartender3.unlock then
						Bartender3:Lock()
					else
						Bartender3:Unlock()
					end
				end,
				disabled = function() return InCombatLockdown() end,
			},
			zoom = {
				order = 3,
				name = "Button Zoom",
				type = "toggle",
				desc = "Toggle the Button Zoom",
				get = function() return Bartender3.db.profile.Zoomed end,
				set = function(z)
					Bartender3:SetZoom(z)
				end,
			},
			tooltip = {
				order = 4,
				name = "Button Tooltip",
				type = "toggle",
				desc = "Toggle the Button Tooltip",
				get = function() return not Bartender3.db.profile.HideTooltip end,
				set = function(h)
					Bartender3.db.profile.HideTooltip = not h
				end,
			},
			selfcast = {
				order = 5,
				name = "Self Casting",
				desc = "Configute Self Casting options",
				type = "group",
				args = {
					modifier = {
						order = 1,
						name = "Modifier SelfCast",
						desc = "SelfCast using CTRL/ALT/SHIFT",
						type = "text",
						get = function() return Bartender3.db.profile.SelfCastModifier end,
						set = function(scm)
							Bartender3:SwitchSelfCastModifier(scm)
						end,
						validate = {"ctrl", "alt", "shift", "none"},
					},
					rightclick = {
						order = 2,
						name = "RightClick SelfCast",
						desc = "SelfCast using Right click",
						type = "toggle",
						get = function() return Bartender3.db.profile.SelfCastRightClick end,
						set = function(v)
							Bartender3.db.profile.SelfCastRightClick = v
							for i,v in pairs(Bartender3.actionbars) do
								if v then v:UpdateSelfCast() end
							end
						end,
					},
				},
				disabled = function() return InCombatLockdown() end,
			},
			cooldown = {
				order = 6,
				name = "Cooldown Count",
				desc = "Toggle the Cooldown Count",
				type = "toggle",
				get = function() return Bartender3.db.profile.ShowCooldown end,
				set = function(sc) 
					Bartender3.db.profile.ShowCooldown = sc 
					for i,v in pairs(Bartender3.actionbars) do
						if v and v.config.Enabled then
							for k,b in pairs(v.buttonobjects) do
								b:UpdateCooldown()
							end
						end
					end
				end,
			}
		},
	}
	
	local bars = {
		{"bar1", "Bar 1", 1, 0},
		{"bar2", "Bar 2", 2, 0},
		{"bar3", "Bar 3", 3, 0},
		{"bar4", "Bar 4", 4, 0},
		{"bar5", "Bar 5", 5, 0},
		{"bar6", "Bar 6", 6, 0},
		{"bar7", "Bar 7", 7, 0},
		{"bar8", "Bar 8", 8, 0},
		{"bar9", "Bar 9", 9, 0},
		{"bar10", "Bar 10", 10, 0},
		{"stancebar", "Stance Bar", "STANCE", 1},
		{"petbar", "Pet Bar", "PET", 1},
		{"menubar", "Micro Menu Bar", "MICROMENU", 1},
		{"bagbar", "Bag Bar", "BAGS", 1},
	}
	for i,bar in ipairs(bars) do
		local object = self:GetBarObject(bar[3], bar[4])
		local maxbuttons = object and #object.buttons or self:GetConfig(bar[3], bar[4]).Buttons
		maxbuttons = (maxbuttons > 1) and maxbuttons or 2 -- ugly hack
		self.options.args[bar[1]] = {
			order = (30+i), 
			name = bar[2],
			type = "group",
			desc = "Configuration for the "..bar[2],
			args = {
				hide = {
					order = 2,
					name = "Hide",
					type = "toggle",
					desc = "Hide the "..bar[2],
					get = function() return self:GetConfig(bar[3], bar[4]).Hide end,
					set = function() self:GetBarObject(bar[3], bar[4]):ToggleVisibilty() end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[3], bar[4]).Enabled end,
				},
				rows = {
					order = 4,
					name = "Rows",
					type = "range",
					desc = "Change the rows of the Bar",
					max = maxbuttons, min = 1, step = 1,
					get = function() return self:GetConfig(bar[3], bar[4]).Rows end,
					set = function(r) 
						self:GetBarObject(bar[3], bar[4]):SetRows(r)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[3], bar[4]).Enabled end,
				},
				padding = {
					order = 5,
					name = "Padding",
					type = "range",
					desc = "Padding of the bar.",
					min = -10, max = 30, step = 1,
					get = function() return self:GetConfig(bar[3], bar[4]).Padding end,
					set = function(p)
						self:GetBarObject(bar[3], bar[4]):SetPadding(p)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[3], bar[4]).Enabled end,
				},
				scale = {
					order = 6,
					name = "Scale",
					type = "range",
					desc = "Scale of the bar.",
					min = .1, max = 5, step = 0.05,
					isPercent = true,
					get = function() return self:GetConfig(bar[3], bar[4]).Scale end,
					set = function(s)
						self:GetBarObject(bar[3], bar[4]):SetScale(s)
					end,
					disabled = function() return InCombatLockdown() or not self:GetConfig(bar[3], bar[4]).Enabled end,
				},
				alpha = {
					order = 7,
					name = "Alpha",
					type = "range",
					desc = "Alpha of the bar.",
					min = .1, max = 1,
					get = function() return self:GetConfig(bar[3], bar[4]).Alpha end,
					set = function(a)
						self:GetBarObject(bar[3], bar[4]):SetAlpha(a)
					end,
					disabled = function() return not self:GetConfig(bar[3], bar[4]).Enabled end,
				},
			}
		}
		if i <= 10 then
			self.options.args[bar[1]].args["enabled"] = {
				order = 1,
				name = "Enabled",
				type = "toggle",
				desc = "Enable "..bar[2],
				get = function() return self:GetConfig(bar[3], bar[4]).Enabled end,
				set = function() Bartender3:ToggleBarEnabled(i) end,
				disabled = function() return InCombatLockdown() end,
			}
		end
	end
	self.options.args.bagbar.args.keyring = {
		order = 10,
		name = "Keyring",
		type = "toggle",
		desc = "Toggle the Keyring",
		get = function() return self.db.profile.SpecialBars["BAGS"].Keyring end,
		set = function()
			self.specialbars["BAGS"]:ToggleKeyring()
		end,
		disabled = function() return InCombatLockdown() end,
	}
	self.options.args.bagbar.args.onebag = {
		order = 11,
		name = "OneBag",
		type = "toggle",
		desc = "Toggle the display of onle one Bag Icon",
		get = function() return self.db.profile.SpecialBars["BAGS"].OneBag end,
		set = function()
			self.specialbars["BAGS"]:ToggleOneBag()
		end,
		disabled = function() return InCombatLockdown() end,
	}
	
	self:RegisterChatCommand({ "/bar", "/bartender3", "/bt3" }, self.options )
	self.options.args.standby = nil
end
